Received: from malur.postgresql.org ([217.196.149.56]) by arkaria.postgresql.org with esmtp (Exim 4.80) (envelope-from ) id 1XbVFr-0003wR-Qx for pgsql-performance@arkaria.postgresql.org; Tue, 07 Oct 2014 13:56:43 +0000 Received: from localhost ([127.0.0.1] helo=postgresql.org) by malur.postgresql.org with smtp (Exim 4.80) (envelope-from ) id 1XbVFr-0007NI-03 for pgsql-performance@arkaria.postgresql.org; Tue, 07 Oct 2014 13:56:43 +0000 Received: from magus.postgresql.org ([2a02:c0:301:0:ffff::29]) by malur.postgresql.org with esmtps (TLS1.2:DHE_RSA_AES_256_CBC_SHA256:256) (Exim 4.80) (envelope-from ) id 1XbVFo-0007Hs-E6 for pgsql-performance@postgresql.org; Tue, 07 Oct 2014 13:56:40 +0000 Received: from sss.pgh.pa.us ([66.207.139.130]) by magus.postgresql.org with esmtps (TLS1.2:DHE_RSA_AES_256_CBC_SHA256:256) (Exim 4.80) (envelope-from ) id 1XbVFk-0005WJ-Ph for pgsql-performance@postgresql.org; Tue, 07 Oct 2014 13:56:39 +0000 Received: from sss1.sss.pgh.pa.us (localhost [127.0.0.1]) by sss.pgh.pa.us (8.14.4/8.14.4) with ESMTP id s97DuY2s022484; Tue, 7 Oct 2014 09:56:34 -0400 From: Tom Lane To: Vladimir Kamarzin cc: pgsql-performance@postgresql.org Subject: Re: Performance degradation in 324577f39bc8738ed0ec24c36c5cb2c2f81ec660 In-reply-to: <29191412676815@web25o.yandex.ru> References: <29191412676815@web25o.yandex.ru> Comments: In-reply-to Vladimir Kamarzin message dated "Tue, 07 Oct 2014 16:13:35 +0600" Date: Tue, 07 Oct 2014 09:56:34 -0400 Message-ID: <22483.1412690194@sss.pgh.pa.us> X-Pg-Spam-Score: -1.9 (-) List-Archive: List-Help: List-ID: List-Owner: List-Post: List-Subscribe: List-Unsubscribe: X-Mailing-List: pgsql-performance Precedence: bulk Sender: pgsql-performance-owner@postgresql.org Vladimir Kamarzin writes: > After upgrade from 9.3.1 to 9.3.5 we expirienced a slight performance degradation of all queries. Query time increased to some amount of ms, mostly in range of 100ms. Some actions in our application results in a lot of small queries and in such cases performance degradation is very significant - total action performs for a 2-3 times longer then before (15s -> 40s, etc). > Using git-bisect we've found a bad revision causes performance drop: it is 324577f39bc8738ed0ec24c36c5cb2c2f81ec660 Hm. If you're going to do queries that involve update/delete across large inheritance trees, that bug fix is unavoidably going to cost you some cycles. Having said that, though, the append_rel_list data structures aren't especially large or complex, so it's a mite astonishing that you could notice this extra copying cost in the context of everything else that happens in a large inherited UPDATE. I am wondering if you've misidentified the commit that made the difference --- especially since you claim there's a penalty for "all" queries, which there manifestly couldn't be with this particular patch. If not, there must be something rather unusual about your queries or schema. Care to provide a self-contained test case? regards, tom lane -- Sent via pgsql-performance mailing list (pgsql-performance@postgresql.org) To make changes to your subscription: http://www.postgresql.org/mailpref/pgsql-performance